Different modes
===============
*Tools → Options → General* allows switching Thonny's user interface to one of three different modes.

Regular mode
------------
This is the default mode. Nothing much to say about this.

Simple mode
-----------
In this mode the menus are hidden and Variables view gets automatically opened. 
Use a small link in the upper-right corner of the main window to return to regular mode.

Expert mode
-----------
This mode looks almost like regular mode, but has some extra features, which are
useful for teachers.

* View menu gets an extra item *Full screen* which puts Thonny to full screen.
* Double clicking on the tab of an editor or view maximizes this editor or view. Unmaximize by double clicking the tab again.
* Tools menu gets an extra item *Open replayer...* which allows replaying user action logs.   

